Class: Brute::Middleware::DefaultCompactionPipeline::Declines

Inherits:
Object
  • Object
show all
Defined in:
lib/brute/middleware/040_default_compaction_pipeline.rb

Overview

The floor of a pipeline given nothing to summarise with: what the free layers managed is what the turn gets.

Instance Method Summary collapse

Instance Method Details

#call(env) ⇒ Object



96
# File 'lib/brute/middleware/040_default_compaction_pipeline.rb', line 96

def call(env) = env