Module: Brute::Prompts::BuildSwitch

Defined in:
lib/brute/prompts/build_switch.rb

Constant Summary collapse

TEXT =
<<~TXT
  <system-reminder>
  Your operational mode has changed from plan to build.
  You are no longer in read-only mode.
  You are permitted to make file changes, run shell commands, and utilize your arsenal of tools as needed.
  </system-reminder>
TXT

Class Method Summary collapse

Class Method Details

.call(_ctx) ⇒ Object



14
15
16
# File 'lib/brute/prompts/build_switch.rb', line 14

def self.call(_ctx)
  TEXT
end