Module: Brute::Prompts::CodeReferences

Defined in:
lib/brute/prompts/code_references.rb

Constant Summary collapse

TEXT =
<<~'TXT'
  # Code References
  When referencing specific functions or pieces of code include the pattern `file_path:line_number` to allow the user to easily navigate to the source code location.

  <example>
  user: Where are errors from the client handled?
  assistant: Clients are marked as failed in the `connectToServer` function in src/services/process.ts:712.
  </example>
TXT

Class Method Summary collapse

Class Method Details

.call(_ctx) ⇒ Object



16
17
18
# File 'lib/brute/prompts/code_references.rb', line 16

def self.call(_ctx)
  TEXT
end