Module: Brute::Prompts::FrontendTasks
- Defined in:
- lib/brute/prompts/frontend_tasks.rb
Constant Summary collapse
- TEXT =
<<~TXT # Frontend tasks When doing frontend design tasks, avoid collapsing into bland, generic layouts. - Ensure the page loads properly on both desktop and mobile. - Overall: Avoid boilerplate layouts and interchangeable UI patterns. Vary themes, type families, and visual languages across outputs. Exception: If working within an existing website or design system, preserve the established patterns, structure, and visual language. TXT
Class Method Summary collapse
Class Method Details
.call(_ctx) ⇒ Object
16 17 18 |
# File 'lib/brute/prompts/frontend_tasks.rb', line 16 def self.call(_ctx) TEXT end |