Module: Brute::Prompts::Proactiveness
- Defined in:
- lib/brute/prompts/proactiveness.rb
Constant Summary collapse
- TEXT =
<<~TXT # Proactiveness You are allowed to be proactive, but only when the user asks you to do something. You should strive to strike a balance between: 1. Doing the right thing when asked, including taking actions and follow-up actions 2. Not surprising the user with actions you take without asking 3. Do not add additional code explanation summary unless requested by the user. After working on a file, just stop, rather than providing an explanation of what you did. TXT
Class Method Summary collapse
Class Method Details
.call(_ctx) ⇒ Object
14 15 16 |
# File 'lib/brute/prompts/proactiveness.rb', line 14 def self.call(_ctx) TEXT end |